( cd opt/kde/lib ; rm -rf libkdenetwork.so.2 )
( cd opt/kde/lib ; ln -sf libkdenetwork.so.2.0.0 libkdenetwork.so.2 )
( cd opt/kde/lib ; rm -rf libmimelib.so )
( cd opt/kde/lib ; ln -sf libmimelib.so.1.0.1 libmimelib.so )
( cd opt/kde/lib ; rm -rf libmimelib.so.1 )
( cd opt/kde/lib ; ln -sf libmimelib.so.1.0.1 libmimelib.so.1 )
( cd opt/kde/lib ; rm -rf libkdenetwork.so )
( cd opt/kde/lib ; ln -sf libkdenetwork.so.2.0.0 libkdenetwork.so )
( cd opt/kde/share/doc/HTML/en/kit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpf ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/korn ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/korn ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kppp ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kppp ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/krfb ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/krfb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/lisa ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/lisa ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/knewsticker ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/knewsticker ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdict ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmail ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/knode ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/knode ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksirc ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksirc ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kcontrol/lanbrowser ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kcmtalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kcmtalkd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kxmlrpcd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kxmlrpcd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ktalkd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kgpgcertmanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/en/common common )
